(function ($) {
  'use strict';

  Drupal.behaviors.euccx = {
    attach: function (context, settings) {
      $('#cookie-tabs').tabs();

      $(window).load(function() {
        var cookieBlock = $('#cookie-tabs');
        if (cookieBlock.length) {
          Drupal.euccx.handleSwitches();
        }
        Drupal.euccx.removeOffendingCookies();
      });

      $('body').on('click', '.cookie-settings-save', function(e) {
        try {
          e.preventDefault();
          // Make sure that the EU Cookie Compliance Module has set its cookie
          Drupal.eu_cookie_compliance.acceptAction();
          var plugin;
          // Create our cookie content
          var cookieData = '';
          $('#cookie-tabs input').each(function() {
            if ($(this).prop('checked')) {
              plugin = $(this).attr("name").match(/-[^-]+$/)[0].substring(1);
              cookieData += plugin + "|";
            }
          });
          // ... and set our cookie
          Drupal.euccx.setCookie(cookieData);
        } catch (e) {
          // Nothing to do here. Something went terribly wrong.
        }
      });
    }
  };

  Drupal.euccx = {};

  // This is using the exact same code with EU Cookie since our cookie is also
  // respecting most of the settings that the user supplied in EU Cookie
  // Compliance module.
  Drupal.euccx.setCookie = function(content) {
    try {
      var date = new Date();
      var domain = Drupal.settings.eu_cookie_compliance.domain ? 
        Drupal.settings.eu_cookie_compliance.domain : 
        '';
      var path = Drupal.settings.basePath;
      var cookieName = 'cookie-extras-agreed';
      if (path.length > 1) {
        var pathEnd = path.length - 1;
        if (path.lastIndexOf('/') === pathEnd) {
          path = path.substring(0, pathEnd);
        }
      }
      var cookieSession = parseInt(
        Drupal.settings.eu_cookie_compliance.cookie_session
      );

      if (cookieSession) {
        $.cookie(cookieName, content, { path: path, domain: domain });
      } else {
        var lifetime = parseInt(
          Drupal.settings.eu_cookie_compliance.cookie_lifetime
        );
        date.setDate(date.getDate() + lifetime);
        $.cookie(cookieName, content, { 
          expires: date, 
          path: path, 
          domain: domain 
        });
      }

      // Store consent if applicable.
      if (Drupal.settings.eu_cookie_compliance.store_consent) {
        var url = Drupal.settings.basePath;
        url += Drupal.settings.pathPrefix;
        url += 'eu-cookie-compliance/store_consent/banner';

        $.post(url, {}, function (data) { });
      }

    } catch(e) {
    }

  }

  // The switches in the block are always set to off. It's up to us to turn them
  // on, if the cookie stored tells us so.
  Drupal.euccx.handleSwitches = function() {
    // If the cookie is not set, just turn them on by default
    var cookieValue = $.cookie('cookie-extras-agreed');
    if (typeof(cookieValue) === 'undefined' || (cookieValue === null)) {
      $('#cookie-tabs input').prop('checked', true);
    } else {
      var plugins = Drupal.settings.euccx_plugins;
      for (var i = 0; i < plugins.length; i++) {
        var input = $("input[name*='" + plugins[i] + "']");
        if (input.length && (cookieValue.indexOf(plugins[i]) !== -1)) {
          input.prop('checked', true);
        }
      }
    }
  }

  Drupal.euccx.removeOffendingCookies = function() {
    if (Drupal.settings.euccx_cookies && 
      (Drupal.settings.euccx_cookies instanceof Array)) {
      try {
        for (var i = 0; i < Drupal.settings.euccx_cookies.length; i++) {
          var ctd = Drupal.settings.euccx_cookies[i];
          document.cookie = ctd + '=; expires=Thu, 01 Jan 1970 00:00:01 GMT;';
        }
      } catch(e) {
      }
    }
  }
})(jQuery);
